# Copyright (c) 2023-2025 Arista Networks, Inc.
# Use of this source code is governed by the Apache License 2.0
# that can be found in the LICENSE file.
"""Test inputs for anta.tests.field_notices."""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING, Any

from anta.models import AntaTest
from anta.result_manager.models import AntaTestStatus
from anta.tests.field_notices import VerifyFieldNotice44Resolution, VerifyFieldNotice72Resolution
from tests.units.anta_tests import test

if TYPE_CHECKING:
    from tests.units.anta_tests import AntaUnitTestData

DATA: AntaUnitTestData = {
    (VerifyFieldNotice44Resolution, "success"): {
        "eos_data": [
            {
                "imageFormatVersion": "1.0",
                "uptime": 1109144.35,
                "modelName": "DCS-7280QRA-C36S",
                "details": {
                    "deviations": [],
                    "components": [{"name": "Aboot", "version": "Aboot-veos-8.0.0-3255441"}, {"name": "NotAboot", "version": "Aboot-veos-8.0.0-3255441"}],
                },
            }
        ],
        "expected": {"result": AntaTestStatus.SUCCESS},
    },
    (VerifyFieldNotice44Resolution, "failure-4.0"): {
        "eos_data": [
            {
                "imageFormatVersion": "1.0",
                "uptime": 1109144.35,
                "modelName": "DCS-7280QRA-C36S",
                "details": {"deviations": [], "components": [{"name": "Aboot", "version": "Aboot-veos-4.0.1-3255441"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["Device is running incorrect version of aboot 4.0.1"]},
    },
    (VerifyFieldNotice44Resolution, "failure-4.1"): {
        "eos_data": [
            {
                "imageFormatVersion": "1.0",
                "uptime": 1109144.35,
                "modelName": "DCS-7280QRA-C36S",
                "details": {"deviations": [], "components": [{"name": "Aboot", "version": "Aboot-veos-4.1.0-3255441"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["Device is running incorrect version of aboot 4.1.0"]},
    },
    (VerifyFieldNotice44Resolution, "failure-6.0"): {
        "eos_data": [
            {
                "imageFormatVersion": "1.0",
                "uptime": 1109144.35,
                "modelName": "DCS-7280QRA-C36S",
                "details": {"deviations": [], "components": [{"name": "Aboot", "version": "Aboot-veos-6.0.1-3255441"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["Device is running incorrect version of aboot 6.0.1"]},
    },
    (VerifyFieldNotice44Resolution, "failure-6.1"): {
        "eos_data": [
            {
                "imageFormatVersion": "1.0",
                "uptime": 1109144.35,
                "modelName": "DCS-7280QRA-C36S",
                "details": {"deviations": [], "components": [{"name": "Aboot", "version": "Aboot-veos-6.1.1-3255441"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["Device is running incorrect version of aboot 6.1.1"]},
    },
    (VerifyFieldNotice44Resolution, "skipped-model"): {
        "eos_data": [
            {
                "imageFormatVersion": "1.0",
                "uptime": 1109144.35,
                "modelName": "vEOS-lab",
                "details": {"deviations": [], "components": [{"name": "Aboot", "version": "Aboot-veos-8.0.0-3255441"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.SKIPPED, "messages": ["Device is not impacted by FN044"]},
    },
    (VerifyFieldNotice44Resolution, "failure-no-aboot-component"): {
        "eos_data": [
            {
                "imageFormatVersion": "1.0",
                "uptime": 1109144.35,
                "modelName": "DCS-7280QRA-C36S",
                "details": {"deviations": [], "components": [{"name": "NotAboot", "version": "Aboot-veos-4.0.1-3255441"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["Aboot component not found"]},
    },
    (VerifyFieldNotice72Resolution, "success-JPE"): {
        "eos_data": [
            {
                "modelName": "DCS-7280SR3-48YC8",
                "serialNumber": "JPE2130000",
                "details": {"deviations": [], "components": [{"name": "FixedSystemvrm1", "version": "7"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.SUCCESS, "messages": ["FN72 is mitigated"]},
    },
    (VerifyFieldNotice72Resolution, "success-JAS"): {
        "eos_data": [
            {
                "modelName": "DCS-7280SR3-48YC8",
                "serialNumber": "JAS2040000",
                "details": {"deviations": [], "components": [{"name": "FixedSystemvrm1", "version": "7"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.SUCCESS, "messages": ["FN72 is mitigated"]},
    },
    (VerifyFieldNotice72Resolution, "success-K-JPE"): {
        "eos_data": [
            {
                "modelName": "DCS-7280SR3K-48YC8",
                "serialNumber": "JPE2133000",
                "details": {"deviations": [], "components": [{"name": "FixedSystemvrm1", "version": "7"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.SUCCESS, "messages": ["FN72 is mitigated"]},
    },
    (VerifyFieldNotice72Resolution, "success-K-JAS"): {
        "eos_data": [
            {
                "modelName": "DCS-7280SR3K-48YC8",
                "serialNumber": "JAS2040000",
                "details": {"deviations": [], "components": [{"name": "FixedSystemvrm1", "version": "7"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.SUCCESS, "messages": ["FN72 is mitigated"]},
    },
    (VerifyFieldNotice72Resolution, "skipped-Serial"): {
        "eos_data": [
            {
                "modelName": "DCS-7280SR3K-48YC8",
                "serialNumber": "BAN2040000",
                "details": {"deviations": [], "components": [{"name": "FixedSystemvrm1", "version": "7"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.SKIPPED, "messages": ["Device not exposed"]},
    },
    (VerifyFieldNotice72Resolution, "skipped-Platform"): {
        "eos_data": [
            {"modelName": "DCS-7150-52-CL", "serialNumber": "JAS0040000", "details": {"deviations": [], "components": [{"name": "FixedSystemvrm1", "version": "5"}]}}
        ],
        "expected": {"result": AntaTestStatus.SKIPPED, "messages": ["Platform is not impacted by FN072"]},
    },
    (VerifyFieldNotice72Resolution, "skipped-range-JPE"): {
        "eos_data": [
            {
                "modelName": "DCS-7280SR3-48YC8",
                "serialNumber": "JPE2131000",
                "details": {"deviations": [], "components": [{"name": "FixedSystemvrm1", "version": "5"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.SKIPPED, "messages": ["Device not exposed"]},
    },
    (VerifyFieldNotice72Resolution, "skipped-range-K-JPE"): {
        "eos_data": [
            {
                "modelName": "DCS-7280SR3K-48YC8",
                "serialNumber": "JPE2134000",
                "details": {"deviations": [], "components": [{"name": "FixedSystemvrm1", "version": "5"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.SKIPPED, "messages": ["Device not exposed"]},
    },
    (VerifyFieldNotice72Resolution, "skipped-range-JAS"): {
        "eos_data": [
            {
                "modelName": "DCS-7280SR3-48YC8",
                "serialNumber": "JAS2041000",
                "details": {"deviations": [], "components": [{"name": "FixedSystemvrm1", "version": "5"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.SKIPPED, "messages": ["Device not exposed"]},
    },
    (VerifyFieldNotice72Resolution, "skipped-range-K-JAS"): {
        "eos_data": [
            {
                "modelName": "DCS-7280SR3K-48YC8",
                "serialNumber": "JAS2041000",
                "details": {"deviations": [], "components": [{"name": "FixedSystemvrm1", "version": "5"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.SKIPPED, "messages": ["Device not exposed"]},
    },
    (VerifyFieldNotice72Resolution, "failed-JPE"): {
        "eos_data": [
            {
                "modelName": "DCS-7280SR3K-48YC8",
                "serialNumber": "JPE2133000",
                "details": {"deviations": [], "components": [{"name": "FixedSystemvrm1", "version": "5"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["Device is exposed to FN72"]},
    },
    (VerifyFieldNotice72Resolution, "failed-JAS"): {
        "eos_data": [
            {
                "modelName": "DCS-7280SR3-48YC8",
                "serialNumber": "JAS2040000",
                "details": {"deviations": [], "components": [{"name": "FixedSystemvrm1", "version": "5"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["Device is exposed to FN72"]},
    },
    (VerifyFieldNotice72Resolution, "error"): {
        "eos_data": [
            {
                "modelName": "DCS-7280SR3-48YC8",
                "serialNumber": "JAS2040000",
                "details": {"deviations": [], "components": [{"name": "FixedSystemvrm2", "version": "5"}]},
            }
        ],
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["Error in running test - Component FixedSystemvrm1 not found in 'show version"]},
    },
}



# Copyright (c) 2023-2025 Arista Networks, Inc.
# Use of this source code is governed by the Apache License 2.0
# that can be found in the LICENSE file.
"""Tests for anta.tests module."""

from __future__ import annotations

import asyncio
from typing import TYPE_CHECKING, Any, Literal, TypedDict

from anta.models import AntaTest

if TYPE_CHECKING:
    import sys

    from anta.device import AntaDevice
    from anta.result_manager.models import AntaTestStatus

    if sys.version_info >= (3, 11):
        from typing import NotRequired
    else:
        from typing_extensions import NotRequired

    from typing import TypeAlias


class AtomicResult(TypedDict):
    """Expected atomic result of a unit test of an AntaTest subclass."""

    description: str
    result: Literal[AntaTestStatus.SUCCESS, AntaTestStatus.FAILURE, AntaTestStatus.SKIPPED]
    messages: NotRequired[list[str]]
    inputs: NotRequired[dict[str, Any]]


class UnitTestResult(TypedDict):
    """Expected result of a unit test of an AntaTest subclass.

    For our AntaTest unit tests we expect only success, failure or skipped.
    Never unset nor error.
    """

    result: Literal[AntaTestStatus.SUCCESS, AntaTestStatus.FAILURE, AntaTestStatus.SKIPPED]
    messages: NotRequired[list[str]]
    atomic_results: NotRequired[list[AtomicResult]]


class AntaUnitTest(TypedDict):
    """The parameters required for a unit test of an AntaTest subclass."""

    inputs: NotRequired[dict[str, Any]]
    eos_data: list[dict[str, Any] | str]
    expected: UnitTestResult


AntaUnitTestData: TypeAlias = dict[tuple[type[AntaTest], str], AntaUnitTest]


def test(device: AntaDevice, anta_test: type[AntaTest], unit_test_data: AntaUnitTest) -> None:
    """Generic test function for AntaTest subclass.

    Generate unit tests for each AntaTest subclass.

    See `tests/units/anta_tests/README.md` for more information on how to use it.
    """
    # Instantiate the AntaTest subclass
    test_instance = anta_test(device, inputs=unit_test_data.get("inputs"), eos_data=unit_test_data["eos_data"])
    # Run the test() method
    asyncio.run(test_instance.test())

    # Assert expected result
    assert test_instance.result.result == unit_test_data["expected"]["result"], (
        f"Expected '{unit_test_data['expected']['result']}' result, got '{test_instance.result.result}'. Messages: {test_instance.result.messages}"
    )
    # Assert test messages
    if "messages" in unit_test_data["expected"]:
        # Assert number of messages
        assert len(test_instance.result.messages) == len(unit_test_data["expected"]["messages"]), (
            f"Expected {len(unit_test_data['expected']['messages'])} messages, got {len(test_instance.result.messages)}"
        )
        # Test will pass if the expected message is included in the test result message
        for message, expected in zip(test_instance.result.messages, unit_test_data["expected"]["messages"], strict=True):
            assert expected in message, f"Expected message '{expected}' not found in '{message}'"
    else:
        # Test result should not have messages
        assert test_instance.result.messages == [], "There are untested messages, see diffs with '-vv' option"

    # Assert atomic results
    if "atomic_results" in unit_test_data["expected"]:
        # Assert number of atomic results
        assert len(test_instance.result.atomic_results) == len(unit_test_data["expected"]["atomic_results"]), (
            f"Expected {len(unit_test_data['expected']['atomic_results'])} atomic results, got {len(test_instance.result.atomic_results)}"
        )
        # Assert each atomic result
        for atomic_result_model, expected_atomic_result in zip(test_instance.result.atomic_results, unit_test_data["expected"]["atomic_results"], strict=True):
            atomic_result = atomic_result_model.model_dump(mode="json", exclude_none=True)
            messages = atomic_result.pop("messages")
            expected_messages = expected_atomic_result.pop("messages", [])

            # First assert the rest of the atomic result
            assert atomic_result == expected_atomic_result, "Expected atomic result did not match, see diffs with '-vv' option"

            # Then assert the messages if any
            if expected_messages:
                # We expect messages in atomic test result
                assert len(messages) == len(expected_messages), (
                    f"Expected {len(expected_messages)} messages, got {len(messages)} in atomic result "
                    f"with description '{atomic_result['description']}', see diffs with '-vv' option"
                )
                # Test will pass if the expected message is included in the atomic test result message
                for message, expected in zip(messages, expected_messages, strict=True):
                    assert expected in message, f"Expected message '{expected}' not found in '{message}'"
            else:
                # Atomic test result should not have messages
                assert messages == [], f"There are untested messages in atomic result with description '{atomic_result['description']}', see diffs with '-vv' option"
    else:
        # Test result should not have atomic results
        assert test_instance.result.atomic_results == [], "There are untested atomic results, see diffs with '-vv' option"



# Copyright (c) 2023-2025 Arista Networks, Inc.
# Use of this source code is governed by the Apache License 2.0
# that can be found in the LICENSE file.
"""Tests for anta.tests.mlag.py."""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING, Any

from anta.models import AntaTest
from anta.result_manager.models import AntaTestStatus
from anta.tests.mlag import VerifyMlagConfigSanity, VerifyMlagDualPrimary, VerifyMlagInterfaces, VerifyMlagPrimaryPriority, VerifyMlagReloadDelay, VerifyMlagStatus
from tests.units.anta_tests import test

if TYPE_CHECKING:
    from tests.units.anta_tests import AntaUnitTestData

DATA: AntaUnitTestData = {
    (VerifyMlagStatus, "success"): {
        "eos_data": [{"state": "active", "negStatus": "connected", "peerLinkStatus": "up", "localIntfStatus": "up"}],
        "expected": {"result": AntaTestStatus.SUCCESS},
    },
    (VerifyMlagStatus, "skipped"): {
        "eos_data": [{"state": "disabled"}],
        "expected": {"result": AntaTestStatus.SKIPPED, "messages": ["MLAG is disabled"]},
    },
    (VerifyMlagStatus, "failure-negotiation-status"): {
        "eos_data": [{"state": "active", "negStatus": "connecting", "peerLinkStatus": "up", "localIntfStatus": "up"}],
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["MLAG negotiation status mismatch - Expected: connected Actual: connecting"]},
    },
    (VerifyMlagStatus, "failure-local-interface"): {
        "eos_data": [{"state": "active", "negStatus": "connected", "peerLinkStatus": "up", "localIntfStatus": "down"}],
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["Operational state of the MLAG local interface is not correct - Expected: up Actual: down"]},
    },
    (VerifyMlagStatus, "failure-peer-link"): {
        "eos_data": [{"state": "active", "negStatus": "connected", "peerLinkStatus": "down", "localIntfStatus": "up"}],
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["Operational state of the MLAG peer link is not correct - Expected: up Actual: down"]},
    },
    (VerifyMlagInterfaces, "success"): {
        "eos_data": [{"state": "active", "mlagPorts": {"Disabled": 0, "Configured": 0, "Inactive": 0, "Active-partial": 0, "Active-full": 1}}],
        "expected": {"result": AntaTestStatus.SUCCESS},
    },
    (VerifyMlagInterfaces, "skipped"): {
        "eos_data": [{"state": "disabled"}],
        "expected": {"result": AntaTestStatus.SKIPPED, "messages": ["MLAG is disabled"]},
    },
    (VerifyMlagInterfaces, "failure-active-partial"): {
        "eos_data": [{"state": "active", "mlagPorts": {"Disabled": 0, "Configured": 0, "Inactive": 0, "Active-partial": 1, "Active-full": 1}}],
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["MLAG status is not ok - Inactive Ports: 0 Partial Active Ports: 1"]},
    },
    (VerifyMlagInterfaces, "failure-inactive"): {
        "eos_data": [{"state": "active", "mlagPorts": {"Disabled": 0, "Configured": 0, "Inactive": 1, "Active-partial": 1, "Active-full": 1}}],
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["MLAG status is not ok - Inactive Ports: 1 Partial Active Ports: 1"]},
    },
    (VerifyMlagConfigSanity, "success"): {
        "eos_data": [{"globalConfiguration": {}, "interfaceConfiguration": {}, "mlagActive": True, "mlagConnected": True}],
        "expected": {"result": AntaTestStatus.SUCCESS},
    },
    (VerifyMlagConfigSanity, "skipped"): {
        "eos_data": [{"mlagActive": False}],
        "expected": {"result": AntaTestStatus.SKIPPED, "messages": ["MLAG is disabled"]},
    },
    (VerifyMlagConfigSanity, "failure-global"): {
        "eos_data": [
            {
                "globalConfiguration": {"mlag": {"globalParameters": {"dual-primary-detection-delay": {"localValue": "0", "peerValue": "200"}}}},
                "interfaceConfiguration": {},
                "mlagActive": True,
                "mlagConnected": True,
            }
        ],
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["MLAG config-sanity found in global configuration"]},
    },
    (VerifyMlagConfigSanity, "failure-interface"): {
        "eos_data": [
            {
                "globalConfiguration": {},
                "interfaceConfiguration": {"trunk-native-vlan mlag30": {"interface": {"Port-Channel30": {"localValue": "123", "peerValue": "3700"}}}},
                "mlagActive": True,
                "mlagConnected": True,
            }
        ],
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["MLAG config-sanity found in interface configuration"]},
    },
    (VerifyMlagReloadDelay, "success"): {
        "eos_data": [{"state": "active", "reloadDelay": 300, "reloadDelayNonMlag": 330}],
        "inputs": {"reload_delay": 300, "reload_delay_non_mlag": 330},
        "expected": {"result": AntaTestStatus.SUCCESS},
    },
    (VerifyMlagReloadDelay, "skipped-disabled"): {
        "eos_data": [{"state": "disabled"}],
        "inputs": {"reload_delay": 300, "reload_delay_non_mlag": 330},
        "expected": {"result": AntaTestStatus.SKIPPED, "messages": ["MLAG is disabled"]},
    },
    (VerifyMlagReloadDelay, "failure"): {
        "eos_data": [{"state": "active", "reloadDelay": 400, "reloadDelayNonMlag": 430}],
        "inputs": {"reload_delay": 300, "reload_delay_non_mlag": 330},
        "expected": {
            "result": AntaTestStatus.FAILURE,
            "messages": ["MLAG reload-delay mismatch - Expected: 300s Actual: 400s", "Delay for non-MLAG ports mismatch - Expected: 330s Actual: 430s"],
        },
    },
    (VerifyMlagDualPrimary, "success"): {
        "eos_data": [
            {
                "state": "active",
                "dualPrimaryDetectionState": "configured",
                "dualPrimaryPortsErrdisabled": False,
                "dualPrimaryMlagRecoveryDelay": 60,
                "dualPrimaryNonMlagRecoveryDelay": 0,
                "detail": {"dualPrimaryDetectionDelay": 200, "dualPrimaryAction": "none"},
            }
        ],
        "inputs": {"detection_delay": 200, "errdisabled": False, "recovery_delay": 60, "recovery_delay_non_mlag": 0},
        "expected": {"result": AntaTestStatus.SUCCESS},
    },
    (VerifyMlagDualPrimary, "skipped-disabled"): {
        "eos_data": [{"state": "disabled"}],
        "inputs": {"detection_delay": 200, "errdisabled": False, "recovery_delay": 60, "recovery_delay_non_mlag": 0},
        "expected": {"result": AntaTestStatus.SKIPPED, "messages": ["MLAG is disabled"]},
    },
    (VerifyMlagDualPrimary, "failure-disabled"): {
        "eos_data": [{"state": "active", "dualPrimaryDetectionState": "disabled", "dualPrimaryPortsErrdisabled": False}],
        "inputs": {"detection_delay": 200, "errdisabled": False, "recovery_delay": 60, "recovery_delay_non_mlag": 0},
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["Dual-primary detection is disabled"]},
    },
    (VerifyMlagDualPrimary, "failure-wrong-timers"): {
        "eos_data": [
            {
                "state": "active",
                "dualPrimaryDetectionState": "configured",
                "dualPrimaryPortsErrdisabled": False,
                "dualPrimaryMlagRecoveryDelay": 160,
                "dualPrimaryNonMlagRecoveryDelay": 0,
                "detail": {"dualPrimaryDetectionDelay": 300, "dualPrimaryAction": "none"},
            }
        ],
        "inputs": {"detection_delay": 200, "errdisabled": False, "recovery_delay": 60, "recovery_delay_non_mlag": 0},
        "expected": {
            "result": AntaTestStatus.FAILURE,
            "messages": [
                "Dual-primary detection delay mismatch - Expected: 200 Actual: 300",
                "Dual-primary MLAG recovery delay mismatch - Expected: 60 Actual: 160",
            ],
        },
    },
    (VerifyMlagDualPrimary, "failure-wrong-action"): {
        "eos_data": [
            {
                "state": "active",
                "dualPrimaryDetectionState": "configured",
                "dualPrimaryPortsErrdisabled": False,
                "dualPrimaryMlagRecoveryDelay": 60,
                "dualPrimaryNonMlagRecoveryDelay": 0,
                "detail": {"dualPrimaryDetectionDelay": 200, "dualPrimaryAction": "none"},
            }
        ],
        "inputs": {"detection_delay": 200, "errdisabled": True, "recovery_delay": 60, "recovery_delay_non_mlag": 0},
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["Dual-primary action mismatch - Expected: errdisableAllInterfaces Actual: none"]},
    },
    (VerifyMlagDualPrimary, "failure-wrong-non-mlag-delay"): {
        "eos_data": [
            {
                "state": "active",
                "dualPrimaryDetectionState": "configured",
                "dualPrimaryPortsErrdisabled": False,
                "dualPrimaryMlagRecoveryDelay": 60,
                "dualPrimaryNonMlagRecoveryDelay": 120,
                "detail": {"dualPrimaryDetectionDelay": 200, "dualPrimaryAction": "errdisableAllInterfaces"},
            }
        ],
        "inputs": {"detection_delay": 200, "errdisabled": True, "recovery_delay": 60, "recovery_delay_non_mlag": 60},
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["Dual-primary non MLAG recovery delay mismatch - Expected: 60 Actual: 120"]},
    },
    (VerifyMlagPrimaryPriority, "success"): {
        "eos_data": [{"state": "active", "detail": {"mlagState": "primary", "primaryPriority": 32767}}],
        "inputs": {"primary_priority": 32767},
        "expected": {"result": AntaTestStatus.SUCCESS},
    },
    (VerifyMlagPrimaryPriority, "skipped-disabled"): {
        "eos_data": [{"state": "disabled"}],
        "inputs": {"primary_priority": 32767},
        "expected": {"result": AntaTestStatus.SKIPPED, "messages": ["MLAG is disabled"]},
    },
    (VerifyMlagPrimaryPriority, "failure-not-primary"): {
        "eos_data": [{"state": "active", "detail": {"mlagState": "secondary", "primaryPriority": 32767}}],
        "inputs": {"primary_priority": 32767},
        "expected": {"result": AntaTestStatus.FAILURE, "messages": ["The device is not set as MLAG primary"]},
    },
    (VerifyMlagPrimaryPriority, "failure-incorrect-priority"): {
        "eos_data": [{"state": "active", "detail": {"mlagState": "secondary", "primaryPriority": 32767}}],
        "inputs": {"primary_priority": 1},
        "expected": {
            "result": AntaTestStatus.FAILURE,
            "messages": ["The device is not set as MLAG primary", "MLAG primary priority mismatch - Expected: 1 Actual: 32767"],
        },
    },
}
